@@ -1,11 +1,19 @@
-use strict;
-use warnings;
-package Dist::Zilla::App::Command::add 6.016; # TRIAL
+package Dist::Zilla::App::Command::add 6.018; # TRIAL
 # ABSTRACT: add a module to a dist
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 use Dist::Zilla::App -command;
 use Dist::Zilla::Path;
 
+use namespace::autoclean;
+
 #pod =head1 SYNOPSIS
 #pod
 #pod Adds a new module to a Dist::Zilla-based distribution
@@ -90,7 +98,7 @@ Dist::Zilla::App::Command::add - add a module to a dist
 
 =head1 VERSION
 
-version 6.016
+version 6.018
 
 =head1 SYNOPSIS
 
@@ -101,13 +109,24 @@ Adds a new module to a Dist::Zilla-based distribution
 There are two arguments, C<-p> and C<-P>. C<-P> specify the minting profile
 provider and C<-p> - the profile name. These work just like C<dzil new>.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
 Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
