@@ -1,8 +1,14 @@
-use strict;
-use warnings;
-package Dist::Zilla::App::Command::authordeps 6.016; # TRIAL
+package Dist::Zilla::App::Command::authordeps 6.018; # TRIAL
 # ABSTRACT: List your distribution's author dependencies
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 use Dist::Zilla::App -command;
 
 #pod =head1 SYNOPSIS
@@ -64,7 +70,7 @@ Dist::Zilla::App::Command::authordeps - List your distribution's author dependen
 
 =head1 VERSION
 
-version 6.016
+version 6.018
 
 =head1 SYNOPSIS
 
@@ -81,13 +87,24 @@ In order to add authordeps to all distributions that use a certain plugin bundle
 (or plugin), just list them as prereqs of that bundle (e.g.: using
 L<Dist::Zilla::Plugin::Prereqs> ).
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
 Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
