@@ -1,8 +1,14 @@
-use strict;
-use warnings;
-package Dist::Zilla::App::Command::listdeps 6.016; # TRIAL
+package Dist::Zilla::App::Command::listdeps 6.018; # TRIAL
 # ABSTRACT: print your distribution's prerequisites
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 use Dist::Zilla::App -command;
 
 #pod =head1 SYNOPSIS
@@ -194,7 +200,7 @@ Dist::Zilla::App::Command::listdeps - print your distribution's prerequisites
 
 =head1 VERSION
 
-version 6.016
+version 6.018
 
 =head1 SYNOPSIS
 
@@ -207,6 +213,17 @@ command, which prints your distribution's prerequisites. You could pipe that
 list to a CPAN client like L<cpan> to install all of the dependencies in one
 quick go.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 OPTIONS
 
 =head2 --author (or --develop)
@@ -261,7 +278,7 @@ Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
