@@ -1,8 +1,14 @@
-use strict;
-use warnings;
-package Dist::Zilla::App::Tester 6.016; # TRIAL
+package Dist::Zilla::App::Tester 6.018; # TRIAL
 # ABSTRACT: testing library for Dist::Zilla::App
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 use parent 'App::Cmd::Tester::CaptureExternal';
 use App::Cmd::Tester 0.306 (); # result_class, ->app
 
@@ -19,6 +25,8 @@ use Sub::Exporter -setup => {
   groups  => [ default   => [ qw(test_dzil) ] ],
 };
 
+use namespace::autoclean -except => 'import';
+
 sub result_class { 'Dist::Zilla::App::Tester::Result' }
 
 sub test_dzil {
@@ -43,7 +51,7 @@ sub test_dzil {
 }
 
 {
-  package Dist::Zilla::App::Tester::Result 6.016; # TRIAL
+  package Dist::Zilla::App::Tester::Result 6.018; # TRIAL
 
   BEGIN { our @ISA = qw(App::Cmd::Tester::Result); }
 
@@ -126,7 +134,7 @@ Dist::Zilla::App::Tester - testing library for Dist::Zilla::App
 
 =head1 VERSION
 
-version 6.016
+version 6.018
 
 =head1 DESCRIPTION
 
@@ -160,13 +168,24 @@ The folder where the distribution was built.
 
 =back
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
 Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
