@@ -1,9 +1,17 @@
-package Dist::Zilla::MVP::Assembler::GlobalConfig 6.016; # TRIAL
+package Dist::Zilla::MVP::Assembler::GlobalConfig 6.018; # TRIAL
 # ABSTRACT: Dist::Zilla::MVP::Assembler for global configuration
 
 use Moose;
 extends 'Dist::Zilla::MVP::Assembler';
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 use namespace::autoclean;
 
 #pod =head1 OVERVIEW
@@ -59,7 +67,7 @@ Dist::Zilla::MVP::Assembler::GlobalConfig - Dist::Zilla::MVP::Assembler for glob
 
 =head1 VERSION
 
-version 6.016
+version 6.018
 
 =head1 OVERVIEW
 
@@ -71,6 +79,17 @@ They get registered via the C<register_stash> method, below, generally called
 by the C<register_component> method on L<Dist::Zilla::Role::Stash>-performing
 class.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 register_stash
@@ -86,7 +105,7 @@ Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
