@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::AutoPrereqs 6.016; # TRIAL
+package Dist::Zilla::Plugin::AutoPrereqs 6.018; # TRIAL
 # ABSTRACT: automatically extract prereqs from your modules
 
 use Moose;
@@ -8,6 +8,14 @@ with(
   'Dist::Zilla::Role::PPI',
 );
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 use Moose::Util::TypeConstraints 'enum';
 use namespace::autoclean;
 
@@ -166,7 +174,7 @@ Dist::Zilla::Plugin::AutoPrereqs - automatically extract prereqs from your modul
 
 =head1 VERSION
 
-version 6.016
+version 6.018
 
 =head1 SYNOPSIS
 
@@ -195,6 +203,17 @@ scanned:
     encoding = bytes
     match    = ^t/data/
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 finder
@@ -257,7 +276,7 @@ Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
