@@ -1,13 +1,22 @@
-package Dist::Zilla::Plugin::GatherDir 6.016; # TRIAL
+package Dist::Zilla::Plugin::GatherDir 6.018; # TRIAL
 # ABSTRACT: gather all the files in a directory
 
 use Moose;
-use Dist::Zilla::Types qw(Path);
-use Dist::Zilla::Util;
 with 'Dist::Zilla::Role::FileGatherer';
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 use namespace::autoclean;
 
+use Dist::Zilla::Types qw(Path);
+use Dist::Zilla::Util;
+
 #pod =head1 DESCRIPTION
 #pod
 #pod This is a very, very simple L<FileGatherer|Dist::Zilla::Role::FileGatherer>
@@ -256,7 +265,7 @@ Dist::Zilla::Plugin::GatherDir - gather all the files in a directory
 
 =head1 VERSION
 
-version 6.016
+version 6.018
 
 =head1 DESCRIPTION
 
@@ -286,6 +295,17 @@ subdir of your dist, you might write:
   root   = ~/projects/my-project/spec
   prefix = spec
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 root
@@ -340,7 +360,7 @@ Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
