@@ -1,10 +1,18 @@
-package Dist::Zilla::Plugin::GatherFile 6.016; # TRIAL
+package Dist::Zilla::Plugin::GatherFile 6.018; # TRIAL
 # ABSTRACT: gather individual file(s)
 
 use Moose;
 use Dist::Zilla::Types qw(Path ArrayRefOfPaths);
 with 'Dist::Zilla::Role::FileGatherer';
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 use MooseX::Types::Moose 'ArrayRef';
 use Path::Tiny;
 use Dist::Zilla::File::OnDisk;
@@ -145,7 +153,7 @@ Dist::Zilla::Plugin::GatherFile - gather individual file(s)
 
 =head1 VERSION
 
-version 6.016
+version 6.018
 
 =head1 SYNOPSIS
 
@@ -163,6 +171,17 @@ Since normally every distribution will use a GatherDir plugin, you would only
 need to use the GatherFile plugin if the file was already being excluded (e.g.
 from an C<exclude_match> configuration).
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 root
@@ -187,7 +206,7 @@ Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
