@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::GenerateFile 6.016; # TRIAL
+package Dist::Zilla::Plugin::GenerateFile 6.018; # TRIAL
 # ABSTRACT: build a custom file from only the plugin configuration
 
 use Moose;
@@ -7,6 +7,14 @@ with (
   'Dist::Zilla::Role::TextTemplate',
 );
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 use namespace::autoclean;
 
 use Dist::Zilla::File::InMemory;
@@ -167,7 +175,7 @@ Dist::Zilla::Plugin::GenerateFile - build a custom file from only the plugin con
 
 =head1 VERSION
 
-version 6.016
+version 6.018
 
 =head1 SYNOPSIS
 
@@ -203,6 +211,17 @@ through L<Text::Template>.  The variables C<$plugin> and C<$dist> will be
 provided, set to the [GenerateFile] plugin and the L<Dist::Zilla> object
 respectively.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 filename
@@ -230,7 +249,7 @@ Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
