@@ -1,9 +1,17 @@
-package Dist::Zilla::Plugin::MetaNoIndex 6.016; # TRIAL
+package Dist::Zilla::Plugin::MetaNoIndex 6.018; # TRIAL
 # ABSTRACT: Stop CPAN from indexing stuff
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 use namespace::autoclean;
 
 #pod =encoding utf8
@@ -131,7 +139,7 @@ Dist::Zilla::Plugin::MetaNoIndex - Stop CPAN from indexing stuff
 
 =head1 VERSION
 
-version 6.016
+version 6.018
 
 =head1 SYNOPSIS
 
@@ -156,6 +164,17 @@ that are used for those purposes only, and are not part of the distribution.
 It does this by adding a C<no_index> block to your F<META.json> (or
 F<META.yml>) file in your distribution.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 directories
@@ -203,7 +222,7 @@ Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
