@@ -1,9 +1,17 @@
-package Dist::Zilla::Plugin::MetaResources 6.016; # TRIAL
+package Dist::Zilla::Plugin::MetaResources 6.018; # TRIAL
 # ABSTRACT: provide arbitrary "resources" for distribution metadata
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 use namespace::autoclean;
 
 #pod =head1 DESCRIPTION
@@ -93,7 +101,7 @@ Dist::Zilla::Plugin::MetaResources - provide arbitrary "resources" for distribut
 
 =head1 VERSION
 
-version 6.016
+version 6.018
 
 =head1 DESCRIPTION
 
@@ -107,6 +115,17 @@ This plugin adds resources entries to the distribution's metadata.
   repository.web    = http://github.com/dude/project
   repository.type   = git
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 SEE ALSO
 
 Dist::Zilla roles: L<MetaProvider|Dist::Zilla::Role::MetaProvider>.
@@ -119,7 +138,7 @@ Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
