@@ -1,9 +1,17 @@
-package Dist::Zilla::Plugin::TestRelease 6.016; # TRIAL
+package Dist::Zilla::Plugin::TestRelease 6.018; # TRIAL
 # ABSTRACT: extract archive and run tests before releasing the dist
 
 use Moose;
 with 'Dist::Zilla::Role::BeforeRelease';
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 use namespace::autoclean;
 
 #pod =head1 DESCRIPTION
@@ -73,7 +81,7 @@ Dist::Zilla::Plugin::TestRelease - extract archive and run tests before releasin
 
 =head1 VERSION
 
-version 6.016
+version 6.018
 
 =head1 DESCRIPTION
 
@@ -86,6 +94,17 @@ the release process continues.
 This will set the RELEASE_TESTING and AUTHOR_TESTING env vars while running the
 test suite.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 CREDITS
 
 This plugin was originally contributed by Christopher J. Madsen.
@@ -96,7 +115,7 @@ Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
