@@ -1,8 +1,17 @@
-package Dist::Zilla::Plugin::UploadToCPAN 6.016; # TRIAL
+package Dist::Zilla::Plugin::UploadToCPAN 6.018; # TRIAL
 # ABSTRACT: upload the dist to CPAN
 
 use Moose;
-with qw(Dist::Zilla::Role::BeforeRelease Dist::Zilla::Role::Releaser);
+with 'Dist::Zilla::Role::BeforeRelease',
+     'Dist::Zilla::Role::Releaser';
+
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
 
 use File::Spec;
 use Moose::Util::TypeConstraints;
@@ -315,7 +324,7 @@ Dist::Zilla::Plugin::UploadToCPAN - upload the dist to CPAN
 
 =head1 VERSION
 
-version 6.016
+version 6.018
 
 =head1 SYNOPSIS
 
@@ -342,6 +351,17 @@ blank username or password will abort the release.
 
 You can't put your password in your F<dist.ini>.  C'mon now!
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 credentials_stash
@@ -406,7 +426,7 @@ Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
