@@ -1,9 +1,17 @@
-package Dist::Zilla::PluginBundle::Basic 6.016; # TRIAL
+package Dist::Zilla::PluginBundle::Basic 6.018; # TRIAL
 # ABSTRACT: the basic plugins to maintain and release CPAN dists
 
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 use namespace::autoclean;
 
 sub configure {
@@ -78,7 +86,7 @@ Dist::Zilla::PluginBundle::Basic - the basic plugins to maintain and release CPA
 
 =head1 VERSION
 
-version 6.016
+version 6.018
 
 =head1 DESCRIPTION
 
@@ -148,6 +156,17 @@ L<Dist::Zilla::Plugin::UploadToCPAN>
 
 =back
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 SEE ALSO
 
 Core Dist::Zilla plugins: L<@Filter|Dist::Zilla::PluginBundle::Filter>.
@@ -162,7 +181,7 @@ Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
