@@ -1,9 +1,17 @@
-package Dist::Zilla::PluginBundle::Filter 6.016; # TRIAL
+package Dist::Zilla::PluginBundle::Filter 6.018; # TRIAL
 # ABSTRACT: use another bundle, with some plugins removed
 
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle';
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 use namespace::autoclean;
 
 use List::Util 1.33 qw(any);
@@ -105,7 +113,7 @@ Dist::Zilla::PluginBundle::Filter - use another bundle, with some plugins remove
 
 =head1 VERSION
 
-version 6.016
+version 6.018
 
 =head1 SYNOPSIS
 
@@ -132,6 +140,17 @@ Options not prefixed with C<-> will be passed to the bundle to be filtered.
 B<NOTE:> When you filter a bundle you B<SHOULD NOT> include it directly in
 your C<dist.ini> file. This plugin will take care of including it for you.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 SEE ALSO
 
 Core Dist::Zilla plugins: L<@Basic|Dist::Zilla::PluginBundle::Basic>.
@@ -144,7 +163,7 @@ Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
