@@ -1,9 +1,17 @@
-package Dist::Zilla::Role::MintingProfile::ShareDir 6.016; # TRIAL
+package Dist::Zilla::Role::MintingProfile::ShareDir 6.018; # TRIAL
 # ABSTRACT: something that keeps its minting profile in a sharedir
 
 use Moose::Role;
 with 'Dist::Zilla::Role::MintingProfile';
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 use namespace::autoclean;
 
 use File::ShareDir;
@@ -41,20 +49,31 @@ Dist::Zilla::Role::MintingProfile::ShareDir - something that keeps its minting p
 
 =head1 VERSION
 
-version 6.016
+version 6.018
 
 =head1 DESCRIPTION
 
 This role includes L<Dist::Zilla::Role::MintingProfile>, providing a
 C<profile_dir> method that looks in the I<module>'s L<ShareDir|File::ShareDir>.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
 Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
