@@ -1,9 +1,17 @@
-package Dist::Zilla::Role::NameProvider 6.016; # TRIAL
+package Dist::Zilla::Role::NameProvider 6.018; # TRIAL
 # ABSTRACT: something that provides a name for the dist
 
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 #pod =head1 DESCRIPTION
 #pod
 #pod Plugins implementing this role must provide a C<provide_name> method that
@@ -32,7 +40,7 @@ Dist::Zilla::Role::NameProvider - something that provides a name for the dist
 
 =head1 VERSION
 
-version 6.016
+version 6.018
 
 =head1 DESCRIPTION
 
@@ -43,13 +51,24 @@ If a NameProvider offers a name but one has already been set, an
 exception will be raised.  If C<provide_name> returns undef, it will be
 ignored.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
 Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
