@@ -1,8 +1,14 @@
-use strict;
-use warnings;
-package Dist::Zilla::Tutorial 6.016; # TRIAL
+package Dist::Zilla::Tutorial 6.018; # TRIAL
 # ABSTRACT: how to use this "Dist::Zilla" thing
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 use Carp ();
 Carp::confess "you're not meant to use the tutorial, just read it!";
 1;
@@ -148,7 +154,7 @@ Dist::Zilla::Tutorial - how to use this "Dist::Zilla" thing
 
 =head1 VERSION
 
-version 6.016
+version 6.018
 
 =head1 SYNOPSIS
 
@@ -211,6 +217,17 @@ rewrites tests from F<./xt>, adds some information to POD, and builds a
 F<Makefile.PL>.  For more information, you can look at the docs for
 L<@Basic|Dist::Zilla::PluginBundle::Basic> and see the plugins it includes.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 BUILDING YOUR DIST
 
 Maybe we're getting ahead of ourselves, here.  Configuring a bunch of plugins
@@ -283,7 +300,7 @@ Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
