@@ -1,8 +1,14 @@
-use strict;
-use warnings;
-package Test::DZil 6.016; # TRIAL
+package Test::DZil 6.018; # TRIAL
 # ABSTRACT: tools for testing Dist::Zilla plugins
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 use Params::Util qw(_HASH0);
 use JSON::MaybeXS;
 use Scalar::Util qw(blessed);
@@ -22,6 +28,8 @@ use Sub::Exporter -setup => {
   groups  => [ default => [ qw(-all) ] ],
 };
 
+use namespace::autoclean -except => 'import';
+
 #pod =head1 DESCRIPTION
 #pod
 #pod Test::DZil provides routines for writing tests for Dist::Zilla plugins.
@@ -251,12 +259,23 @@ Test::DZil - tools for testing Dist::Zilla plugins
 
 =head1 VERSION
 
-version 6.016
+version 6.018
 
 =head1 DESCRIPTION
 
 Test::DZil provides routines for writing tests for Dist::Zilla plugins.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 FUNCTIONS
 
 =head2 Builder
@@ -354,7 +373,7 @@ Ricardo SIGNES 😏 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
